@@ -8,6 +8,14 @@ from .base import BaseCommand, full_options
 class PackageCommand(BaseCommand):
     command = 'package'
 
+    @property
+    def packaging_formats(self):
+        return [self.output_format]
+
+    @property
+    def default_packaging_format(self):
+        return self.output_format
+
     def package_app(self, app: BaseConfig, **options):
         """
         Package an application.
@@ -16,7 +24,13 @@ class PackageCommand(BaseCommand):
         """
         # Default implementation; nothing to do.
 
-    def _package_app(self, app: BaseConfig, update: bool, **options):
+    def _package_app(
+        self,
+        app: BaseConfig,
+        update: bool,
+        packaging_format: str,
+        **options
+    ):
         """
         Internal method to invoke packaging on a single app.
         Ensures the app exists, and has been updated (if requested) before
@@ -24,7 +38,9 @@ class PackageCommand(BaseCommand):
 
         :param app: The application to package
         :param update: Should the application be updated (and rebuilt) first?
+        :param packaging_format: The format of the packaging artefact to create.
         """
+
         template_file = self.bundle_path(app)
         binary_file = self.binary_path(app)
         if not template_file.exists():
@@ -38,16 +54,31 @@ class PackageCommand(BaseCommand):
         else:
             state = None
 
-        state = self.package_app(app, **full_options(state, options))
+        state = self.package_app(
+            app,
+            packaging_format=packaging_format,
+            **full_options(state, options)
+        )
 
         print()
         print("[{app.app_name}] Packaged {filename}".format(
             app=app,
-            filename=self.distribution_path(app).relative_to(self.base_path),
+            filename=self.distribution_path(
+                app,
+                packaging_format=packaging_format,
+            ).relative_to(self.base_path),
         ))
         return state
 
     def add_options(self, parser):
+        parser.add_argument(
+            '-p',
+            '--packaging-format',
+            dest='packaging_format',
+            help='Packaging format to use.',
+            default=self.default_packaging_format,
+            choices=self.packaging_formats,
+        )
         parser.add_argument(
             '--no-sign',
             dest='sign_app',
@@ -82,6 +113,10 @@ class PackageCommand(BaseCommand):
         else:
             state = None
             for app_name, app in sorted(self.apps.items()):
-                state = self._package_app(app, update=update, **full_options(state, options))
+                state = self._package_app(
+                    app,
+                    update=update,
+                    **full_options(state, options)
+                )
 
         return state
