@@ -4,7 +4,7 @@ from .conftest import DummyCommand
 def test_bundle_path(base_command, my_app, tmp_path):
     bundle_path = base_command.bundle_path(my_app)
 
-    assert bundle_path == tmp_path / 'tester' / 'My App'
+    assert bundle_path == tmp_path / 'tester' / 'dumdum' / 'My App'
 
 
 def test_create_command(base_command):
