@@ -1,3 +1,4 @@
+import subprocess
 from unittest import mock
 
 import pytest
@@ -14,7 +15,7 @@ def test_run_app(first_app_config, tmp_path):
     command.run_app(first_app_config)
 
     command.subprocess.run.assert_called_with(
-        ['open', tmp_path / 'macOS' / 'First App' / 'First App.app'],
+        ['open', str(command.binary_path(first_app_config))],
         check=True
     )
 
@@ -23,13 +24,16 @@ def test_run_app_failed(first_app_config, tmp_path):
     "If there's a problem started the app, an exception is raised"
     command = macOSAppRunCommand(base_path=tmp_path)
     command.subprocess = mock.MagicMock()
-    command.subprocess.run.side_effect = BriefcaseCommandError('problem')
+    command.subprocess.run.side_effect = subprocess.CalledProcessError(
+        cmd=['open', str(command.binary_path(first_app_config))],
+        returncode=1
+    )
 
     with pytest.raises(BriefcaseCommandError):
         command.run_app(first_app_config)
 
     # The run command was still invoked, though
     command.subprocess.run.assert_called_with(
-        ['open', tmp_path / 'macOS' / 'First App' / 'First App.app'],
+        ['open', str(command.binary_path(first_app_config))],
         check=True
     )
